pub(crate) fn cache_block_hash(
block_hashes: &mut U256Map<B256>,
number: U256,
hash: B256,
) -> U256Expand description
Inserts a block hash, discards entries outside the EVM-visible cache, and returns its head.
pub(crate) fn cache_block_hash(
block_hashes: &mut U256Map<B256>,
number: U256,
hash: B256,
) -> U256Inserts a block hash, discards entries outside the EVM-visible cache, and returns its head.