AnvilCacheDB

Struct AnvilCacheDB 

pub struct AnvilCacheDB<T>(pub CacheDB<T>);
A wrapper around [CacheDB] that implements [StateDB].

StateDB is a foreign trait with an orphan-rule constraint, so we cannot implement it directly for CacheDB<T>. This newtype sidesteps the orphan rule while delegating all [Database], [DatabaseCommit] and [DatabaseRef] calls to the inner CacheDB.

Tuple Fields

0: CacheDB<T>

Implementations

Source

impl<T: DatabaseRef<Error = DatabaseError>> AnvilCacheDB<T>

pub fn new(inner: T) -> Self

Methods from Deref<Target = CacheDB<T>>

pub fn insert_contract(&mut self, account: &mut AccountInfo)

Inserts the account’s code into the cache.

Accounts objects and code are stored separately in the cache, this will take the code from the account and instead map it to the code hash.

Note: This will not insert into the underlying external database.

pub fn insert_account_info(&mut self, address: Address, info: AccountInfo)

Inserts account info but not override storage

pub fn load_account( &mut self, address: Address, ) -> Result<&mut DbAccount, <ExtDB as DatabaseRef>::Error>

Returns the account for the given address.

If the account was not found in the cache, it will be loaded from the underlying database.

pub fn insert_account_storage( &mut self, address: Address, slot: Uint<256, 4>, value: Uint<256, 4>, ) -> Result<(), <ExtDB as DatabaseRef>::Error>

Inserts account storage without overriding account info

pub fn replace_account_storage( &mut self, address: Address, storage: HashMap<Uint<256, 4>, Uint<256, 4>, DefaultHashBuilder>, ) -> Result<(), <ExtDB as DatabaseRef>::Error>

Replaces account storage without overriding account info

pub fn pretty_print(&self) -> String

Available on crate feature std only.

Pretty print the cache DB for debugging purposes.